
/*
 * BCD to ASCII table
 *
 * Uses FORTRAN 026 codes plus special IBM PC graphics for weird codes.
 */

unsigned char asciibcd[64] = {
/* 00 */ '0', '1', '2', '3', '4', '5', '6', '7',
/* 10 */ '8', '9', ' ', '=', '\'', ' ', ' ', ' ',
/* 20 */ '+', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
/* 30 */ 'H', 'I', ' ', '.', ')', ' ', ' ', ' ',
/* 40 */ '-', 'J', 'K', 'L', 'M', 'N', 'O', 'P',
/* 50 */ 'Q', 'R', ' ', '$', '*', ' ', ' ', ' ',
/* 60 */ ' ', '/', 'S', 'T', 'U', 'V', 'W', 'X',
/* 70 */ 'Y', 'Z', ' ', ',', '(', ' ', ' ', ' '
};

#if 0
unsigned char asciialt[64] = {
/* 00 */ '0', '1', '2', '3', '4', '5', '6', '7',
/* 10 */ '8', '9', ' ', '=', '\'', ' ', ' ', ' ',
/* 20 */ '+', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
/* 30 */ 'H', 'I', ' ', '.', ')', ' ', ' ', ' ',
/* 40 */ '-', 'J', 'K', 'L', 'M', 'N', 'O', 'P',
/* 50 */ 'Q', 'R', ' ', '$', '*', ' ', ' ', ' ',
/* 60 */ ' ', '/', 'S', 'T', 'U', 'V', 'W', 'X',
/* 70 */ 'Y', 'Z', ' ', ',', '(', ' ', ' ', ' '
};
#endif

unsigned char asciialt[64] = {
/* 00 */ ' ', '1', '2', '3', '4', '5', '6', '7',
/* 10 */ '8', '9', '0', '=', '\'', ':', '>', '{',
/* 20 */ ' ', '/', 'S', 'T', 'U', 'V', 'W', 'X',
/* 30 */ 'Y', 'Z', '|', ',', '(', '~', '\\', '"',
/* 40 */ '-', 'J', 'K', 'L', 'M', 'N', 'O', 'P',
/* 50 */ 'Q', 'R', '!', '$', '*', ']', ';', '_',
/* 60 */ '+', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
/* 70 */ 'H', 'I', '?', '.', ')', '[', '<', '}'
};
